/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin;

import java.util.Objects;

import org.springframework.boot.autoconfigure.data.rest.RepositoryRestProperties;
import org.springframework.hateoas.EntityModel;
import org.springframework.hateoas.Link;
import org.springframework.hateoas.server.RepresentationModelAssembler;
import org.springframework.hateoas.server.mvc.WebMvcLinkBuilder;
import org.springframework.stereotype.Component;

import de.ozgcloud.admin.common.user.CurrentUserService;
import lombok.RequiredArgsConstructor;

@Component
@RequiredArgsConstructor
public class RootModelAssembler implements RepresentationModelAssembler<Root, EntityModel<Root>> {
	static final String REL_CONFIGURATION = "configuration";
	static final String REL_DOCUMENTATIONS = "documentations";

	private final RepositoryRestProperties restProperties;
	private final CurrentUserService currentUserService;
	private final DocumentationProperties documentationProperties;

	@Override
	public EntityModel<Root> toModel(Root root) {
		var rootModel = EntityModel.of(root);
		addLinks(rootModel);
		return rootModel;
	}

	private void addLinks(EntityModel<Root> rootModel) {
		rootModel.add(WebMvcLinkBuilder.linkTo(RootController.class).withSelfRel());
		rootModel.addIf(currentUserService.hasConfigurationPermission(), this::buildConfigLink);
		rootModel.addIf(Objects.nonNull(documentationProperties.getUrl()), () -> Link.of(documentationProperties.getUrl(), REL_DOCUMENTATIONS));
	}

	private Link buildConfigLink() {
		var rootLinkBuilder = WebMvcLinkBuilder.linkTo(RootController.class);
		return Link.of(
				rootLinkBuilder.toUriComponentsBuilder().replacePath(restProperties.getBasePath()).toUriString(),
				REL_CONFIGURATION);
	}
}
