/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.environment;

import static org.springframework.hateoas.server.mvc.WebMvcLinkBuilder.*;

import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import de.ozgcloud.admin.RootController;
import de.ozgcloud.admin.common.FeatureToggleProperties;
import lombok.RequiredArgsConstructor;

@RestController("ozgCloudEnvironmentController")
@RequiredArgsConstructor
@RequestMapping(EnvironmentController.PATH)
public class EnvironmentController {

	static final String PATH = "/api/environment"; // NOSONAR

	private final ProductionProperties environmentProperties;

	private final OAuth2Properties oAuthProperties;

	private final FeatureToggleProperties featureToggleProperties;
	private final FeaturesMapper featuresMapper;

	@GetMapping
	public Environment getEnvironment() {
		return Environment.builder()
				.production(environmentProperties.isProduction())
				.remoteHost(linkTo(RootController.class).toUri().toString())
				.authServer(oAuthProperties.getAuthServerUrl())
				.realm(oAuthProperties.getRealm())
				.clientId(oAuthProperties.getResource())
				.features(featuresMapper.fromFeatureToggleProperties(featureToggleProperties))
				.build();
	}
}
