/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.keycloak;

import java.util.List;

import org.keycloak.admin.client.resource.GroupsResource;
import org.keycloak.representations.idm.GroupRepresentation;
import org.springframework.stereotype.Service;

import jakarta.ws.rs.core.Response;
import lombok.RequiredArgsConstructor;

@Service
@RequiredArgsConstructor
class KeycloakApiService {

	private final GroupsResource groupsResource;

	public List<GroupRepresentation> getAllGroups() {
		return groupsResource.groups("", 0, Integer.MAX_VALUE, false);
	}

	public String addGroup(GroupRepresentation groupRepresentation) {
		try (var response = groupsResource.add(groupRepresentation)) {
			return getCreatedResourceIdFromResponse(response);
		}
	}

	String getCreatedResourceIdFromResponse(Response response) {
		if (response.getStatus() == Response.Status.CREATED.getStatusCode()) {
			return extractResourceIdFromLocationHeader(response.getHeaderString("Location"));
		}
		throw new ResourceCreationException(
				"Failed to add group - got response with status %d (%s) and headers %s".formatted(response.getStatus(), response.getStatusInfo()
						.getReasonPhrase(), response.getHeaders()));
	}

	String extractResourceIdFromLocationHeader(String location) {
		return location.substring(location.lastIndexOf('/') + 1);
	}
}
