/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.organisationseinheit;

import java.util.List;

import org.springframework.data.annotation.Id;
import org.springframework.data.annotation.TypeAlias;
import org.springframework.data.mongodb.core.mapping.Document;

import com.fasterxml.jackson.annotation.JsonIgnore;

import lombok.Builder;
import lombok.Getter;
import lombok.Singular;
import lombok.extern.jackson.Jacksonized;

@Getter
@Builder(toBuilder = true)
@Jacksonized
@Document(language = "german", collection = OrganisationsEinheit.COLLECTION_NAME)
@TypeAlias("OrganisationsEinheit")
public class OrganisationsEinheit {

	static final String COLLECTION_NAME = "organisationsEinheit";
	static final String FIELD_SETTINGS = "settings";

	@JsonIgnore
	@Id
	private String id;
	@JsonIgnore
	private String keycloakId;
	@JsonIgnore
	private String zufiId;
	@JsonIgnore
	private Long lastSyncTimestamp;
	@JsonIgnore
	private String parentId;
	@JsonIgnore
	@Singular
	private List<OrganisationsEinheit> children;

	private String name;
	private String organisationsEinheitId;
	private SyncResult syncResult;
	@Builder.Default
	private OrganisationsEinheitSettings settings = new OrganisationsEinheitSettings(null);
}