/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.organisationseinheit;

import org.springframework.hateoas.CollectionModel;
import org.springframework.hateoas.EntityModel;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PatchMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import lombok.RequiredArgsConstructor;

@RestController
@RequestMapping(OrganisationsEinheitController.PATH)
@RequiredArgsConstructor
public class OrganisationsEinheitController {

	static final String PATH = "/api/organisationseinheits"; // NOSONAR

	private final OrganisationsEinheitService organisationsEinheitService;

	private final OrganisationsEinheitModelAssembler assembler;

	@GetMapping
	public CollectionModel<EntityModel<OrganisationsEinheit>> getAll() {
		var organisationsEinheiten = organisationsEinheitService.getOrganisationsEinheiten();
		return assembler.toCollectionModel(organisationsEinheiten);
	}

	@GetMapping("/{id}")
	public EntityModel<OrganisationsEinheit> getById(@PathVariable String id) {
		return assembler.toModel(organisationsEinheitService.getOrganisationsEinheitById(id));
	}

	@GetMapping("/{id}/children")
	public CollectionModel<EntityModel<OrganisationsEinheit>> getChildren(@PathVariable String id) {
		var children = organisationsEinheitService.getChildren(id);
		return assembler.toChildrenCollectionModel(id, children);
	}

	@PatchMapping("/{id}")
	public EntityModel<OrganisationsEinheit> editOrganisationsEinheit(@PathVariable String id,
			@RequestBody OrganisationsEinheitPatch organisationsEinheitPatch) {
		var patched = organisationsEinheitService.editOrganisationsEinheit(id, organisationsEinheitPatch);
		return assembler.toModel(patched);
	}
}
