/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.organisationseinheit;

import java.util.List;
import java.util.Optional;
import java.util.stream.Stream;

import org.springframework.data.mongodb.repository.MongoRepository;
import org.springframework.data.mongodb.repository.Query;
import org.springframework.data.mongodb.repository.Update;
import org.springframework.stereotype.Repository;

@Repository
interface OrganisationsEinheitRepository extends MongoRepository<OrganisationsEinheit, String> {

	@Query("{'syncResult': {$ne: 'DELETED'}}")
	List<OrganisationsEinheit> findAllNotDeleted();

	@Query("{'syncResult': {$ne: 'DELETED'}, 'parentId': ?0}")
	List<OrganisationsEinheit> findChildren(String parentId);

	@Query("{'syncResult': { $ne: null }, 'keycloakId': ?0}")
	Optional<OrganisationsEinheit> findSyncedByKeycloakId(String keycloakId);

	@Query("{'syncResult': { $ne: null }, 'lastSyncTimestamp': { $lt: ?0 }}")
	@Update("{'$set':  {'syncResult':  'DELETED'}}")
	void setUnsyncedAsDeleted(long lastSyncTimestamp);

	@Query("{'syncResult': null }")
	Stream<OrganisationsEinheit> findAllWithoutSyncResult();
}
