/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.reporting;

import java.util.List;

import de.ozgcloud.admin.common.DtoService;
import de.ozgcloud.admin.common.SettingDtoService;
import de.ozgcloud.admin.setting.SettingConstants;
import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor
@DtoService(SettingConstants.AGGREGATION_MANAGER)
class ReportingAggregationManagerSettingDtoService implements SettingDtoService {

	private final AggregationMappingMapper mapper;

	private final AggregationMappingRepository repository;

	@Override
	public ReportingAggregationManagerSettingDto getDataTransferObject() {
		return mapToDto(repository.findAllBypassAuth());
	}

	ReportingAggregationManagerSettingDto mapToDto(List<AggregationMapping> aggregationMappings) {
		return ReportingAggregationManagerSettingDto.builder()
				.aggregationMappings(aggregationMappings.stream().map(mapper::toMapping).toList())
				.build();
	}

	@Override
	public String getSettingKeyName() {
		return "ozgcloud.aggregation";
	}
}
