/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.common.user;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.ValueSource;
import org.mockito.MockedStatic;

class CurrentUserServiceTest {
	private final CurrentUserService currentUserService = new CurrentUserService();

	@DisplayName("Has role")
	@Nested
	class TestHasRole {
		@ParameterizedTest
		@ValueSource(booleans = { false, true })
		void shouldReturnValue(boolean hasRoleValue) {
			try (MockedStatic<CurrentUserHelper> mockUserHelper = mockStatic(CurrentUserHelper.class)) {
				mockUserHelper.when(() -> CurrentUserHelper.hasRole(anyString()))
						.thenReturn(hasRoleValue);

				boolean hasRole = currentUserService.hasRole(UserRole.ADMIN_ADMIN);

				mockUserHelper.verify(() -> CurrentUserHelper.hasRole(UserRole.ADMIN_ADMIN));
				assertThat(hasRole).isEqualTo(hasRoleValue);
			}
		}
	}

	@Nested
	class TestHasConfigurationPermission {

		@Test
		void shouldCallCurrentUserHelper() {
			try (MockedStatic<CurrentUserHelper> mockUserHelper = mockStatic(CurrentUserHelper.class)) {
				currentUserService.hasConfigurationPermission();

				mockUserHelper.verify(() -> CurrentUserHelper.hasAnyRole(UserRole.CONFIGURATION_ROLES));
			}
		}

		@ParameterizedTest
		@ValueSource(booleans = { false, true })
		void shouldReturnValue(boolean hasConfigurationPermission) {
			try (MockedStatic<CurrentUserHelper> mockUserHelper = mockStatic(CurrentUserHelper.class)) {
				mockUserHelper.when(() -> CurrentUserHelper.hasAnyRole(any())).thenReturn(hasConfigurationPermission);

				var result = currentUserService.hasConfigurationPermission();

				assertThat(result).isEqualTo(hasConfigurationPermission);
			}
		}
	}
}
