/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.environment;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.ValueSource;
import org.mapstruct.factory.Mappers;

import de.ozgcloud.admin.common.FeatureToggleProperties;

class FeaturesMapperTest {

	private FeaturesMapper mapper = Mappers.getMapper(FeaturesMapper.class);

	@Nested
	class TestFromFeatureToggleProperties {

		private final FeatureToggleProperties props = new FeatureToggleProperties();

		@ParameterizedTest
		@ValueSource(booleans = {true, false})
		void shouldMapPostfach(boolean postfach) {
			props.setPostfach(postfach);

			var features = mapper.fromFeatureToggleProperties(props);

			assertThat(features.isPostfach()).isEqualTo(postfach);
		}

		@ParameterizedTest
		@ValueSource(booleans = {true, false})
		void shouldMapBenutzerRollen(boolean benutzerRollen) {
			props.setBenutzerRollen(benutzerRollen);

			var features = mapper.fromFeatureToggleProperties(props);

			assertThat(features.isBenutzerRollen()).isEqualTo(benutzerRollen);
		}
	}
}
