/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.keycloak;

import java.util.List;
import java.util.Map;
import java.util.UUID;

import org.keycloak.representations.idm.GroupRepresentation;

import com.thedeanda.lorem.LoremIpsum;

class GroupRepresentationTestFactory {

	public static final String ORGANIZATIONS_EINHEIT_ID_ATTRIBUTE = "organisationseinheitId";

	public static final String ID = UUID.randomUUID().toString();
	public static final String PARENT_ID = UUID.randomUUID().toString();
	public static final String NAME = LoremIpsum.getInstance().getName();
	public static final String ORGANISATIONS_EINHEIT_ID = UUID.randomUUID().toString();
	public static final Map<String, List<String>> ATTRIBUTES = Map.of(ORGANIZATIONS_EINHEIT_ID_ATTRIBUTE, List.of(ORGANISATIONS_EINHEIT_ID));

	public static final String SUB_GROUP_ID = UUID.randomUUID().toString();
	public static final String SUB_GROUP_NAME = LoremIpsum.getInstance().getName();
	public static final String SUB_GROUP_ORGANISATIONS_EINHEIT_ID = UUID.randomUUID().toString();
	public static final Map<String, List<String>> SUB_GROUP_ATTRIBUTES = Map.of(ORGANIZATIONS_EINHEIT_ID_ATTRIBUTE, List.of(SUB_GROUP_ORGANISATIONS_EINHEIT_ID));

	public static GroupRepresentation create() {
		return create(true);
	}

	public static GroupRepresentation create(String name) {
		var groupRepresentation = create();
		groupRepresentation.setName(name);
		return groupRepresentation;
	}

	public static GroupRepresentation createWithoutId(String name) {
		var groupRepresentation =  create(false);
		groupRepresentation.setName(name);
		return groupRepresentation;
	}

	public static GroupRepresentation create(boolean withId) {
		var groupRepresentation = new GroupRepresentation();
		if (withId) {
			groupRepresentation.setId(ID);
		}
		groupRepresentation.setParentId(PARENT_ID);
		groupRepresentation.setName(NAME);
		groupRepresentation.setAttributes(ATTRIBUTES);
		groupRepresentation.setSubGroups(List.of(createSubGroup(withId)));
		return groupRepresentation;
	}

	private static GroupRepresentation createSubGroup(boolean withId) {
		var groupRepresentation = new GroupRepresentation();
		if (withId) {
			groupRepresentation.setId(SUB_GROUP_ID);
		}
		groupRepresentation.setParentId(ID);
		groupRepresentation.setName(SUB_GROUP_NAME);
		groupRepresentation.setAttributes(SUB_GROUP_ATTRIBUTES);
		return groupRepresentation;
	}
}
