/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.organisationseinheit;

import static org.mockito.Mockito.*;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.*;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.*;

import java.util.List;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.mock.mockito.MockBean;
import org.springframework.security.oauth2.jwt.JwtDecoder;
import org.springframework.security.test.context.support.WithMockUser;
import org.springframework.test.web.servlet.MockMvc;

import de.ozgcloud.common.test.ITCase;
import lombok.SneakyThrows;

@ITCase
@WithMockUser
@AutoConfigureMockMvc
@SpringBootTest(properties = {
		"ozgcloud.keycloak.api.url:test",
		"ozgcloud.keycloak.api.user:test",
		"ozgcloud.keycloak.api.password:test",
		"ozgcloud.keycloak.api.realm:test",
		"ozgcloud.keycloak.api.client:test",
		"ozgcloud.keycloak.api.organisationsEinheitIdKey:test" })
class OrganisationsEinheitITCase {

	private final String PATH = OrganisationsEinheitController.PATH;

	@MockBean
	private OrganisationsEinheitService service;
	@MockBean
	private JwtDecoder decoder;

	@Autowired
	private MockMvc mockMvc;

	@DisplayName("Get all")
	@WithMockUser
	@Nested
	class TestGetAll {

		@BeforeEach
		void init() {
			when(service.getOrganisationsEinheiten()).thenReturn(List.of(OrganisationsEinheitTestFactory.create()));
		}

		@SneakyThrows
		@Test
		void shouldContainList() {
			var response = mockMvc.perform(get(PATH)).andExpect(status().isOk());

			response.andExpect(jsonPath("$._embedded.organisationsEinheits").isNotEmpty());
		}

		@SneakyThrows
		@Test
		void shouldContainOrganisationsEinheit() {
			mockMvc.perform(get(PATH))
					.andExpect(jsonPath("$._embedded.organisationsEinheits[0].name").value(OrganisationsEinheitTestFactory.NAME))
					.andExpect(jsonPath("$._embedded.organisationsEinheits[0].organisationsEinheitId").value(
							OrganisationsEinheitTestFactory.ORGANISATIONS_EINHEIT_ID))
					.andExpect(
							jsonPath("$._embedded.organisationsEinheits[0].syncResult").value(OrganisationsEinheitTestFactory.SYNC_RESULT.name()))
					.andExpect(jsonPath("$._embedded.organisationsEinheits[0].zufiId").doesNotExist())
					.andExpect(jsonPath("$._embedded.organisationsEinheits[0].parentId").doesNotExist())
					.andExpect(jsonPath("$._embedded.organisationsEinheits[0].keycloakId").doesNotExist())
					.andExpect(jsonPath("$._embedded.organisationsEinheits[0].id").doesNotExist());
		}
	}

	@DisplayName("Get by id")
	@WithMockUser
	@Nested
	class TestGetById {

		@BeforeEach
		void init() {
			when(service.getOrganisationsEinheitById(OrganisationsEinheitTestFactory.ID)).thenReturn(OrganisationsEinheitTestFactory.create());
		}

		@SneakyThrows
		@Test
		void shouldReturnOrganisationsEinheit() {
			var response = mockMvc.perform(get(PATH + "/" + OrganisationsEinheitTestFactory.ID)).andExpect(status().isOk());

			response
					.andExpect(jsonPath("$.name").value(OrganisationsEinheitTestFactory.NAME))
					.andExpect(jsonPath("$.organisationsEinheitId").value(
							OrganisationsEinheitTestFactory.ORGANISATIONS_EINHEIT_ID))
					.andExpect(jsonPath("$.syncResult").value(OrganisationsEinheitTestFactory.SYNC_RESULT.name()))
					.andExpect(jsonPath("$.zufiId").doesNotExist())
					.andExpect(jsonPath("$.parentId").doesNotExist())
					.andExpect(jsonPath("$.keycloakId").doesNotExist())
					.andExpect(jsonPath("$.id").doesNotExist());
		}
	}

}