/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.organisationseinheit;

import static org.assertj.core.api.Assertions.*;

import java.util.Collections;
import java.util.Objects;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;

import de.ozgcloud.admin.keycloak.AddGroupData;

class OrganisationsEinheitMapperTest {

	private final OrganisationsEinheitMapper mapper = Mappers.getMapper(OrganisationsEinheitMapper.class);

	@Nested
	class TestFromGrpc {

		@Test
		void shouldMap() {
			var mapped = mapper.fromGrpc(GrpcOrganisationsEinheitTestFactory.create());

			assertThat(mapped)
					.matches(organisationsEinheit -> Objects.isNull(organisationsEinheit.getSettings().getSignatur()))
					.extracting(
							OrganisationsEinheit::getName,
							OrganisationsEinheit::getOrganisationsEinheitId,
							OrganisationsEinheit::getZufiId,
							OrganisationsEinheit::getParentId,
							OrganisationsEinheit::getSyncResult,
							OrganisationsEinheit::getChildren
					).containsExactly(
							OrganisationsEinheitTestFactory.NAME,
							OrganisationsEinheitTestFactory.ORGANISATIONS_EINHEIT_ID,
							OrganisationsEinheitTestFactory.ZUFI_ID,
							null,
							null,
							Collections.emptyList()
					);
		}
	}

	@Nested
	class TestToAddGroupData {

		@Test
		void shouldMap() {
			var mapped = mapper.toAddGroupData(OrganisationsEinheitTestFactory.create());

			assertThat(mapped).extracting(
					AddGroupData::getName,
					AddGroupData::getOrganisationsEinheitId
			).containsExactly(
					OrganisationsEinheitTestFactory.NAME,
					OrganisationsEinheitTestFactory.ORGANISATIONS_EINHEIT_ID
			);
		}
	}
}