/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.organisationseinheit;

import java.time.Instant;
import java.util.UUID;

import com.thedeanda.lorem.LoremIpsum;

public class OrganisationsEinheitTestFactory {

	public static final String ID = UUID.randomUUID().toString();
	public static final String KEYCLOAK_ID = UUID.randomUUID().toString();
	public static final String PARENT_ID = UUID.randomUUID().toString();
	public static final String NAME = LoremIpsum.getInstance().getName();
	public static final String ORGANISATIONS_EINHEIT_ID = UUID.randomUUID().toString();
	public static final String ZUFI_ID = UUID.randomUUID().toString();
	public static final SyncResult SYNC_RESULT = SyncResult.OK;
	public static final long LAST_SYNC_UPDATE = Instant.now().toEpochMilli();
	public static final OrganisationsEinheitSettings SETTINGS = OrganisationsEinheitSettingsTestFactory.create();

	public static OrganisationsEinheit create() {
		return createBuilder().build();
	}

	public static OrganisationsEinheit.OrganisationsEinheitBuilder createBuilder() {
		return OrganisationsEinheit.builder()
				.id(ID)
				.keycloakId(KEYCLOAK_ID)
				.name(NAME)
				.organisationsEinheitId(ORGANISATIONS_EINHEIT_ID)
				.parentId(PARENT_ID)
				.zufiId(ZUFI_ID)
				.syncResult(SYNC_RESULT)
				.settings(SETTINGS)
				.lastSyncTimestamp(LAST_SYNC_UPDATE);
	}

	public static OrganisationsEinheit.OrganisationsEinheitBuilder createNewBuilder() {
		return OrganisationsEinheit.builder()
				.id(UUID.randomUUID().toString())
				.keycloakId(UUID.randomUUID().toString())
				.name(LoremIpsum.getInstance().getName())
				.organisationsEinheitId(UUID.randomUUID().toString())
				.parentId(UUID.randomUUID().toString())
				.zufiId(UUID.randomUUID().toString())
				.syncResult(SyncResult.DELETED)
				.settings(OrganisationsEinheitSettingsTestFactory.createNewBuilder().build())
				.lastSyncTimestamp(LAST_SYNC_UPDATE - 10000);
	}
}
