/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.organisationseinheit;

import static org.assertj.core.api.Assertions.*;
import static org.assertj.core.groups.Tuple.tuple;

import java.time.Instant;
import java.util.List;
import java.util.UUID;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.mock.mockito.SpyBean;
import org.springframework.data.mongodb.core.MongoOperations;
import org.springframework.test.context.ContextConfiguration;

import de.ozgcloud.admin.common.KeycloakInitializer;
import de.ozgcloud.admin.keycloak.Group;
import de.ozgcloud.admin.keycloak.KeycloakRemoteService;
import de.ozgcloud.common.test.DbInitializer;
import de.ozgcloud.common.test.ITCase;

@ITCase
@ContextConfiguration(initializers = { DbInitializer.class, KeycloakInitializer.class })
class SyncAddedOrganisationsEinheitenITCase {

	@Autowired
	private SyncService service;
	@SpyBean
	private KeycloakRemoteService keycloakRemoteService;
	@Autowired
	private MongoOperations operations;

	private final long syncTimestamp = Instant.now().toEpochMilli();

	@BeforeEach
	void clearDatabase() {
		operations.dropCollection(OrganisationsEinheit.class);
	}

	@Test
	void shouldSynchronizeAddedTopLevelGroup() {
		var topLevel = topLevel("shouldSynchronizeAddedTopLevelGroup");
		operations.save(topLevel);

		service.syncAddedOrganisationsEinheiten(syncTimestamp);

		assertThat(keycloakRemoteService.getGroupsWithOrganisationsEinheitId())
				.extracting(Group::getName, Group::getOrganisationsEinheitId, Group::getSubGroups)
				.contains(tuple(topLevel.getName(), topLevel.getOrganisationsEinheitId(), List.of()));
	}

	private static OrganisationsEinheit topLevel(String nameSuffix) {
		return OrganisationsEinheitTestFactory.createBuilder()
				.id(UUID.randomUUID().toString())
				.parentId(null)
				.keycloakId(null)
				.syncResult(null)
				.name("topLevel (%s)".formatted(nameSuffix))
				.build();
	}
}
