/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.organisationseinheit;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.time.Instant;

import org.assertj.core.data.*;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.ArgumentCaptor;
import org.mockito.Captor;
import org.mockito.InjectMocks;
import org.mockito.Mock;

class SyncSchedulerTest {

	@InjectMocks
	private SyncScheduler scheduler;

	@Mock
	private SyncService syncService;

	@Nested
	class TestSyncOrganisationsEinheitenWithKeycloak {

		@Captor
		private ArgumentCaptor<Long> syncTimestampArgumentCaptor;

		@Test
		void shouldSyncOrganisationsEinheitenFromKeycloak() {
			callService();

			verify(syncService).syncOrganisationsEinheitenFromKeycloak(syncTimestampArgumentCaptor.capture());
			assertThatSyncTimestampIsCloseToNow();
		}

		@Test
		void shouldSyncAddedOrganisationsEinheiten() {
			callService();

			verify(syncService).syncAddedOrganisationsEinheiten(syncTimestampArgumentCaptor.capture());
			assertThatSyncTimestampIsCloseToNow();
		}

		private void assertThatSyncTimestampIsCloseToNow() {
			assertThat(syncTimestampArgumentCaptor.getValue()).isCloseTo(Instant.now().toEpochMilli(), Offset.offset(5000L));
		}

		private void callService() {
			scheduler.syncOrganisationsEinheitenWithKeycloak();
		}
	}

}