/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.reporting;

import static org.assertj.core.api.Assertions.*;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.*;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc;
import org.springframework.data.mongodb.core.MongoOperations;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.test.web.servlet.ResultActions;

import de.ozgcloud.admin.reporting.AggregationMapping.Scope;
import de.ozgcloud.admin.reporting.AggregationMapping.Status;
import de.ozgcloud.admin.setting.PropertiesTestFactory;
import de.ozgcloud.common.test.DataITCase;
import lombok.SneakyThrows;

@DataITCase
@AutoConfigureMockMvc
public class AggregationMappingEnvironmentSettingITCase {

	@Autowired
	private MockMvc mockMvc;
	@Autowired
	private MongoOperations mongoOperations;

	@Nested
	class TestGetAggregationSettings {

		@BeforeEach
		void fillDb() {
			fillDbWithAggregationMappings();
		}

		@Test
		@SneakyThrows
		void shouldReturnValuesForAggregationManager() {
			var result = getAggregationSettings();

			assertThat(result.andReturn().getResponse().getContentAsString())
					.isEqualToIgnoringWhitespace(PropertiesTestFactory.createAggregationProperties());
		}

		private ResultActions getAggregationSettings() throws Exception {
			return mockMvc.perform(get("/configserver/OzgCloud_AggregationManager/default"))
					.andExpect(status().isOk());
		}

		private void fillDbWithAggregationMappings() {
			var aggregationMapping1 = AggregationMapping.builder()
					.formIdentifier(AggregationMapping.FormIdentifier.builder()
							.formEngineName(PropertiesTestFactory.FORM_ENGINE_NAME_1)
							.formId(PropertiesTestFactory.FORM_ID_1)
							.build())
					.name(PropertiesTestFactory.NAME_1)
					.parent(PropertiesTestFactory.PARENT_1)
					.status(Status.valueOf(PropertiesTestFactory.STATUS_1))
					.scope(Scope.valueOf(PropertiesTestFactory.SCOPE_1))
					.mapping(AggregationMapping.FieldMapping.builder().sourcePath(PropertiesTestFactory.SOURCE_PATH_1_1)
							.targetPath(PropertiesTestFactory.TARGET_PATH_1_1).build())
					.mapping(AggregationMapping.FieldMapping.builder().sourcePath(PropertiesTestFactory.SOURCE_PATH_1_2)
							.targetPath(PropertiesTestFactory.TARGET_PATH_1_2).build())
					.mapping(AggregationMapping.FieldMapping.builder().sourcePath(PropertiesTestFactory.SOURCE_PATH_1_3)
							.targetPath(PropertiesTestFactory.TARGET_PATH_1_3).build())
					.build();
			var aggregationMapping2 = AggregationMapping.builder()
					.formIdentifier(AggregationMapping.FormIdentifier.builder()
							.formEngineName(PropertiesTestFactory.FORM_ENGINE_NAME_2)
							.formId(PropertiesTestFactory.FORM_ID_2)
							.build())
					.name(PropertiesTestFactory.NAME_2)
					.parent(PropertiesTestFactory.PARENT_2)
					.status(Status.valueOf(PropertiesTestFactory.STATUS_2))
					.scope(Scope.valueOf(PropertiesTestFactory.SCOPE_2))
					.mapping(AggregationMapping.FieldMapping.builder().sourcePath(PropertiesTestFactory.SOURCE_PATH_2_1)
							.targetPath(PropertiesTestFactory.TARGET_PATH_2_1).build())
					.mapping(AggregationMapping.FieldMapping.builder().sourcePath(PropertiesTestFactory.SOURCE_PATH_2_2)
							.targetPath(PropertiesTestFactory.TARGET_PATH_2_2).build())
					.build();

			mongoOperations.dropCollection(AggregationMapping.COLLECTION_NAME);
			mongoOperations.save(aggregationMapping1);
			mongoOperations.save(aggregationMapping2);
		}
	}
}
