/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.reporting;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.MongoOperations;
import org.springframework.security.authorization.AuthorizationDeniedException;
import org.springframework.security.test.context.support.WithMockUser;

import de.ozgcloud.admin.common.user.UserRole;
import de.ozgcloud.admin.setting.SettingTestFactory;
import de.ozgcloud.common.test.DataITCase;

@DataITCase
class AggregationMappingRepositoryITCase {

	@Autowired
	private AggregationMappingRepository repository;

	@Autowired
	private MongoOperations operations;

	@BeforeEach
	void dropCollection() {
		operations.dropCollection(AggregationMapping.COLLECTION_NAME);
	}

	@Nested
	class TestFindAll {
		@Test
		@WithMockUser(roles = UserRole.DATENBEAUFTRAGUNG)
		void shouldLoadOnlyFieldMapping() {
			operations.save(AggregationMappingTestFactory.create());
			operations.save(SettingTestFactory.create());

			var result = repository.findAll();

			assertThat(result).hasSize(1);
		}

		@Test
		@WithMockUser
		void shouldThrowExceptionOnMissingRole() {
			operations.save(AggregationMappingTestFactory.create());

			assertThatThrownBy(() -> repository.findAll()).isInstanceOf(AuthorizationDeniedException.class);
		}
	}

	@Nested
	class TestFindAllBypassAuth {
		@Test
		void shouldLoadWithoutRole() {
			operations.save(AggregationMappingTestFactory.create());

			var result = repository.findAllBypassAuth();

			assertThat(result).hasSize(1);
		}
	}
}
