/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.reporting;

import java.util.UUID;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.admin.reporting.AggregationMapping.FieldMapping;
import de.ozgcloud.admin.reporting.AggregationMapping.FormIdentifier;
import de.ozgcloud.admin.reporting.AggregationMapping.Scope;
import de.ozgcloud.admin.reporting.AggregationMapping.Status;

public class AggregationMappingTestFactory {

	public static final String ID = UUID.randomUUID().toString();
	public static final String NAME = "Test Auswertung";
	public static final String FORM_ENGINE_NAME = "A12";
	public static final String FORM_ID = "42";
	public static final String PARENT = LoremIpsum.getInstance().getName();
	public static final Status STATUS = Status.AUSSTEHEND;
	public static final Scope SCOPE = Scope.MANDANT;

	public static final String SOURCE_PATH = "name";
	public static final String TARGET_PATH = "antragsteller.name";

	public static AggregationMapping create() {
		return createBuilder().build();
	}

	public static AggregationMapping.AggregationMappingBuilder createBuilder() {
		return AggregationMapping.builder()
				.id(UUID.randomUUID().toString())
				.name(NAME)
				.parent(PARENT)
				.status(STATUS)
				.scope(SCOPE)
				.formIdentifier(FormIdentifier.builder()
						.formEngineName(FORM_ENGINE_NAME)
						.formId(FORM_ID)
						.build())
				.mapping(FieldMapping.builder().sourcePath(SOURCE_PATH).targetPath(TARGET_PATH).build());
	}

}
