/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.setting;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.MongoOperations;
import org.springframework.security.test.context.support.WithMockUser;

import de.ozgcloud.admin.common.user.UserRole;
import de.ozgcloud.admin.reporting.AggregationMappingTestFactory;
import de.ozgcloud.common.test.DataITCase;

@DataITCase
@WithMockUser(roles = UserRole.ADMIN_ADMIN)
class SettingRepositoryITCase {

	@Autowired
	private MongoOperations mongoOperations;
	@Autowired
	private SettingRepository repository;

	@Nested
	class TestFindOneByName {
		@Test
		void shouldGetSavedData() {
			mongoOperations.dropCollection(Setting.COLLECTION_NAME);
			mongoOperations.save(SettingTestFactory.create());

			var settingFromDb = repository.findOneByName(SettingTestFactory.SETTING_NAME).get();

			assertThat(settingFromDb).usingRecursiveComparison().ignoringFields("id").isEqualTo(SettingTestFactory.create());
		}
	}

	@Nested
	class TestFindByType {

		@Test
		void shouldReturnOnlySetting() {
			mongoOperations.dropCollection(Setting.COLLECTION_NAME);
			mongoOperations.save(SettingTestFactory.create());
			mongoOperations.save(AggregationMappingTestFactory.create());

			var loaded = repository.findByType("Setting", Setting.class);

			assertThat(loaded).hasSize(1).first().isInstanceOf(Setting.class);
		}
	}
}
