/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.admin.setting.postfach;

import java.util.Map;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.common.test.TestUtils;

public class PostfachSettingBodyTestFactory {
	public static final Absender ABSENDER = AbsenderTestFactory.create();
	public static final String SIGNATUR = LoremIpsum.getInstance().getParagraphs(2, 2);

	public static PostfachSettingBody create() {
		return createBuilder().build();
	}

	public static PostfachSettingBody.PostfachSettingBodyBuilder createBuilder() {
		return PostfachSettingBody.builder()
				.absender(ABSENDER)
				.signatur(SIGNATUR);
	}

	public static String buildPostfachJson(PostfachSettingBody postfach) {
		return TestUtils.loadTextFile("jsonTemplates/settings/createPostfach.json.tmpl", postfach.getAbsender().getName(),
				postfach.getAbsender().getAnschrift(), postfach.getAbsender().getDienst(), postfach.getAbsender().getMandant(),
				postfach.getAbsender().getGemeindeschluessel(), postfach.getSignatur().replaceAll("\n", "\\\\n"));
	}

	public static Map<String, Object> createPostfachAsFlattenedMapVorgangManager() {
		return Map.of("ozgcloud.postfach.absender.name", ABSENDER.getName(),
				"ozgcloud.postfach.absender.anschrift", ABSENDER.getAnschrift(),
				"ozgcloud.postfach.absender.dienst", ABSENDER.getDienst(),
				"ozgcloud.postfach.absender.mandant", ABSENDER.getMandant(),
				"ozgcloud.postfach.absender.gemeinde-schluessel", ABSENDER.getGemeindeschluessel());
	}

	public static Map<String, Object> createPostfachAsFlattenedMapAlfa() {
		return Map.of("ozgcloud.postfach.signatur", SIGNATUR);
	}
}
